@@ -4,11 +4,11 @@ from ddd.tests.dummy_action_test_case import DummyActionTestCase
 
 from ddd.adapters.event.memory.memory_event_adapter import MemoryEventAdapter
 
-from webshop.adapters.listeners.domain.customer_account_created_listener \
-    import CustomerAccountCreatedListener
-from webshop.application.webshop_application_service import \
-    WebshopApplicationService
-from webshop.domain.commands import SendWelcomeEmailCommand
+from shipping.adapters.listeners.domain.shipment_created_listener \
+    import ShipmentCreatedListener
+from shipping.application.shipping_application_service import \
+    ShippingApplicationService
+from shipping.domain.commands import SendTrackingEmailCommand
 
 
 class TestEventAdapter(DummyActionTestCase):
@@ -23,12 +23,12 @@ class TestEventAdapter(DummyActionTestCase):
     ):
         # Setup
         listener = \
-            CustomerAccountCreatedListener(
-                action="send_welcome_email",
+            ShipmentCreatedListener(
+                action="send_tracking_email",
                 service=None,
                 command_creator=lambda event:
-                SendWelcomeEmailCommand(
-                    customer_id=event.customer_id,
+                SendTrackingEmailCommand(
+                    shipment_id=event.shipment_id,
                     token=None,
                 )
             )
@@ -37,19 +37,21 @@ class TestEventAdapter(DummyActionTestCase):
             listener
         ])
 
-        service = WebshopApplicationService(
+        service = ShippingApplicationService(
+            customer_repository=None,
             db_service=None,
             domain_adapter=None,
             domain_publisher=None,
             event_repository=None,
             interchange_adapter=None,
             interchange_publisher=None,
-            job_service=None,
             job_adapter=None,
+            job_service=None,
             log_service=None,
             scheduler_adapter=None,
-            customer_repository=None,
+            shipment_repository=None,
             max_concurrent_actions=10,
+            loop=None,
         )
 
         # Exercise
